var MainHandler = (function () {
    function MainHandler(cvs) {
        var _this = this;
        this.InitGuiElements = function () {
            _this.crossProductLabelElement = document.getElementById('crossProductLabel');
            _this.dotProductLabelElement = document.getElementById('dotProductLabel');
        };
        this.paint = function (time) {
            window.requestAnimationFrame(_this.paint);
            /* calculate the vectors between v2, v1 and v3, v1 */
            var vec1x = _this.mp2.getX() - _this.mp1.getX();
            var vec1y = _this.mp2.getY() - _this.mp1.getY();
            var vec2x = _this.mp3.getX() - _this.mp1.getX();
            var vec2y = _this.mp3.getY() - _this.mp1.getY();
            /* note: cross product is the same as the perp-dotproduct */
            var crossProduct = vec1x * vec2y - vec1y * vec2x;
            var dotProduct = vec1x * vec2x + vec1y * vec2y;
            _this.cvsContext.save();
            /* fill background */
            _this.cvsContext.fillStyle = "#EEBC74";
            _this.cvsContext.fillRect(0, 0, _this.canvasHtmlElement.width, _this.canvasHtmlElement.height);
            /* draw lines */
            _this.cvsContext.strokeStyle = "#646464";
            _this.cvsContext.beginPath();
            _this.cvsContext.lineWidth = 1;
            _this.cvsContext.moveTo(_this.mp1.getX(), _this.mp1.getY());
            _this.cvsContext.lineTo(_this.mp2.getX(), _this.mp2.getY());
            _this.cvsContext.stroke();
            _this.cvsContext.beginPath();
            _this.cvsContext.moveTo(_this.mp1.getX(), _this.mp1.getY());
            _this.cvsContext.lineTo(_this.mp3.getX(), _this.mp3.getY());
            _this.cvsContext.stroke();
            /* draw line to complete parallelogram */
            _this.cvsContext.strokeStyle = "#CC7D5D";
            _this.cvsContext.lineWidth = 0.5;
            _this.cvsContext.beginPath();
            _this.cvsContext.moveTo(_this.mp2.getX(), _this.mp2.getY());
            _this.cvsContext.lineTo(_this.mp2.getX() + vec2x, _this.mp2.getY() + vec2y);
            _this.cvsContext.stroke();
            _this.cvsContext.beginPath();
            _this.cvsContext.moveTo(_this.mp3.getX(), _this.mp3.getY());
            _this.cvsContext.lineTo(_this.mp3.getX() + vec1x, _this.mp3.getY() + vec1y);
            _this.cvsContext.stroke();
            /* draw points */
            _this.cvsContext.strokeStyle = "#000000";
            _this.mp1.draw();
            _this.mp2.draw();
            _this.mp3.draw();
            /* print values */
            //this.cvsContext.font = '12px Roboto';
            //this.cvsContext.strokeStyle = "#FF2222";
            //this.cvsContext.strokeText("CrossProduct: " + crossProduct.toString(), 10, 20);
            //this.cvsContext.strokeText("DotProduct: " + dotProduct.toString(), 10, 50);
            _this.cvsContext.restore();
            _this.crossProductLabelElement.innerHTML = crossProduct.toString();
            _this.dotProductLabelElement.innerHTML = dotProduct.toString();
        };
        this.mouseDown = function (event) {
            var cursorPosX = event.x - _this.canvasHtmlElement.offsetLeft;
            var cursorPosY = event.y - _this.canvasHtmlElement.offsetTop;
            for (var i = 0; i < _this.mps.length; i++) {
                if (_this.mps[i].startDragging(cursorPosX, cursorPosY)) {
                    _this.canvasHtmlElement.style.cursor = "pointer";
                    break;
                }
            }
        };
        this.mouseUp = function (event) {
            for (var i = 0; i < _this.mps.length; i++) {
                _this.mps[i].stopDragging();
            }
            /* change cursor back to normal */
            _this.canvasHtmlElement.style.cursor = "default";
        };
        this.mouseMove = function (event) {
            var cursorPosX = event.x - _this.canvasHtmlElement.offsetLeft;
            var cursorPosY = event.y - _this.canvasHtmlElement.offsetTop;
            var pointHit = false;
            /* inform each point about new cursor position */
            for (var i = 0; i < _this.mps.length; i++) {
                _this.mps[i].cursorMoved(cursorPosX, cursorPosY);
                /* if cursor is over point, change cursor to hand */
                if (_this.mps[i].isCursorOnPoint(cursorPosX, cursorPosY)) {
                    _this.canvasHtmlElement.style.cursor = "pointer";
                    pointHit = true;
                }
            }
            /* if cursor is over no point, use normal cursor */
            if (!pointHit) {
                _this.canvasHtmlElement.style.cursor = "default";
            }
        };
        this.canvasHtmlElement = cvs;
        this.cvsContext = this.canvasHtmlElement.getContext("2d");
        this.mp1 = new MovablePoint(this.cvsContext, 50, 250, 1);
        this.mp2 = new MovablePoint(this.cvsContext, 250, 100, 2);
        this.mp3 = new MovablePoint(this.cvsContext, 300, 250, 3);
        this.mps = new Array();
        this.mps.push(this.mp1);
        this.mps.push(this.mp2);
        this.mps.push(this.mp3);
        this.canvasHtmlElement.addEventListener("mousedown", this.mouseDown, false);
        this.canvasHtmlElement.addEventListener("mouseup", this.mouseUp, false);
        this.canvasHtmlElement.addEventListener("mousemove", this.mouseMove, false);
        /* get HTML elements and link them to actions */
        this.InitGuiElements();
        this.paint(0);
    }
    return MainHandler;
})();
window.onload = function () {
    //var el = document.getElementById('content');
    //var greeter = new Greeter(el);
    //greeter.start();
    var canvas = document.getElementById('cvs');
    var mainHandler = new MainHandler(canvas);
};
//# sourceMappingURL=app.js.map